@@ -1,4 +1,5 @@
-# (c) 2009-2018 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# -*- coding: utf-8 -*-
+# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license.php
@@ -31,11 +32,11 @@ Realms
    http://<servername:port>/<approot>/pubshare/WsgiDAV/LICENSE
 
 Users
-   A number of username/password pairs can be set for each realm::
+   A number of user_name/password pairs can be set for each realm::
 
-      adduser('pubshare', 'username', 'password', 'description/unused')
+      adduser('pubshare', 'user_name', 'password', 'description/unused')
 
-   would add a username/password pair to realm /pubshare.
+   would add a user_name/password pair to realm /pubshare.
 
 Note: if developers wish to maintain a separate users database, you can
 write your own domain controller for the HTTPAuthenticator. See
@@ -49,9 +50,16 @@ WSGI middleware for resolving Realm and Paths for the WsgiDAV
 application.
 
 Usage::
+   It *must* be configured as the last item on `middleware_stack` list.
 
    from wsgidav.request_resolver import RequestResolver
-   WSGIApp = RequestResolver(InternalWSGIApp)
+   config = {
+        ...,
+        'middleware_stack': [
+            ...,
+            RequestResolver,
+        ],
+    }
 
 The RequestResolver resolves the requested URL to the following values
 placed in the environ dictionary. First it resolves the corresponding
@@ -88,8 +96,8 @@ header, if present, to::
 """
 from wsgidav import util
 from wsgidav.dav_error import HTTP_NOT_FOUND, DAVError
-from wsgidav.request_server import RequestServer
 from wsgidav.middleware import BaseMiddleware
+from wsgidav.request_server import RequestServer
 
 __docformat__ = "reStructuredText"
 
@@ -146,9 +154,8 @@ __docformat__ = "reStructuredText"
 
 
 class RequestResolver(BaseMiddleware):
-
-    def __init__(self):
-        pass
+    def __init__(self, wsgidav_app, next_app, config):
+        super(RequestResolver, self).__init__(wsgidav_app, next_app, config)
 
     def __call__(self, environ, start_response):
         path = environ["PATH_INFO"]
@@ -172,14 +179,19 @@ class RequestResolver(BaseMiddleware):
 
             dav_compliance_level = "1,2"
 
-            if provider is None or provider.isReadOnly() or provider.lockManager is None:
+            if (
+                provider is None
+                or provider.is_readonly()
+                or provider.lock_manager is None
+            ):
                 dav_compliance_level = "1"
 
-            headers = [("Content-Type", "text/html"),
-                       ("Content-Length", "0"),
-                       ("DAV", dav_compliance_level),
-                       ("Date", util.getRfc1123Time()),
-                       ]
+            headers = [
+                ("Content-Type", "text/html"),
+                ("Content-Length", "0"),
+                ("DAV", dav_compliance_level),
+                ("Date", util.get_rfc1123_time()),
+            ]
 
             if environ["wsgidav.config"].get("add_header_MS_Author_Via", False):
                 headers.append(("MS-Author-Via", "DAV"))
@@ -189,8 +201,9 @@ class RequestResolver(BaseMiddleware):
             return
 
         if provider is None:
-            raise DAVError(HTTP_NOT_FOUND,
-                           "Could not find resource provider for '{}'".format(path))
+            raise DAVError(
+                HTTP_NOT_FOUND, "Could not find resource provider for '{}'".format(path)
+            )
 
         # Let the appropriate resource provider for the realm handle the
         # request
