@@ -943,6 +943,10 @@ class RequestServer(object):
         dest_scheme = dest_scheme.lower() if dest_scheme else ""
         url_scheme = environ["wsgi.url_scheme"].lower()
         fwd_scheme = environ.get("HTTP_X_FORWARDED_PROTO", "").lower()
+
+        url_host = environ["HTTP_HOST"].lower()
+        fwd_host = environ.get("HTTP_X_FORWARDED_HOST", "").lower()
+
         if dest_scheme and dest_scheme not in (url_scheme, fwd_scheme):
             self._fail(
                 HTTP_BAD_GATEWAY,
@@ -951,7 +955,7 @@ class RequestServer(object):
                 "rewrite the 'Destination' haeader.\n"
                 "(See https://github.com/mar10/wsgidav/issues/183)",
             )
-        elif dest_netloc and dest_netloc.lower() != environ["HTTP_HOST"].lower():
+        elif dest_netloc and dest_netloc not in (url_host, fwd_host):
             # TODO: this should consider environ["SERVER_PORT"] also
             self._fail(
                 HTTP_BAD_GATEWAY, "Source and destination must have the same host name."
