@@ -1,4 +1,5 @@
-# (c) 2009-2018 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# -*- coding: utf-8 -*-
+# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 """
 Wrapper for ``server_cli``, that restarts the server when source code is
@@ -21,13 +22,14 @@ def run():
     try:
         serverpath = os.path.join(os.path.dirname(__file__), "server_cli.py")
         while True:
-            p = Popen(["python", serverpath] + args,
-                      # stdin=sys.stdin,
-                      # stdout=subprocess.PIPE,
-                      # stderr=subprocess.PIPE,
-                      # preexec_fn, close_fds, shell, cwd, env, universal_newlines, startupinfo,
-                      # creationflags
-                      )
+            p = Popen(
+                ["python", serverpath] + args,
+                # stdin=sys.stdin,
+                # stdout=subprocess.PIPE,
+                # stderr=subprocess.PIPE,
+                # preexec_fn, close_fds, shell, cwd, env, universal_newlines, startupinfo,
+                # creationflags
+            )
             sys.stdout = p.stdout
             sys.stderr = p.stderr
             p.wait()
