@@ -1,28 +1,11 @@
 # -*- coding: utf-8 -*-
-# (c) 2009-2020 Martin Wendt and contributors; see WsgiDAV https://github.com/m ar10/wsgidav
+# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/m ar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license.php
 """
 Miscellaneous support functions for WsgiDAV.
 """
-from email.utils import formatdate, parsedate
-from hashlib import md5
-from pprint import pformat
-from wsgidav import compat
-from wsgidav.dav_error import (
-    as_DAVError,
-    DAVError,
-    get_http_status_string,
-    HTTP_BAD_REQUEST,
-    HTTP_CREATED,
-    HTTP_NO_CONTENT,
-    HTTP_NOT_MODIFIED,
-    HTTP_OK,
-    HTTP_PRECONDITION_FAILED,
-)
-from wsgidav.xml_tools import etree, is_etree_element, make_sub_element, xml_to_bytes
-
 import calendar
 import logging
 import mimetypes
@@ -32,7 +15,23 @@ import socket
 import stat
 import sys
 import time
+from email.utils import formatdate, parsedate
+from hashlib import md5
+from pprint import pformat
 
+from wsgidav import compat
+from wsgidav.dav_error import (
+    HTTP_BAD_REQUEST,
+    HTTP_CREATED,
+    HTTP_NO_CONTENT,
+    HTTP_NOT_MODIFIED,
+    HTTP_OK,
+    HTTP_PRECONDITION_FAILED,
+    DAVError,
+    as_DAVError,
+    get_http_status_string,
+)
+from wsgidav.xml_tools import etree, is_etree_element, make_sub_element, xml_to_bytes
 
 __docformat__ = "reStructuredText"
 
@@ -970,7 +969,7 @@ def get_etag(file_path):
         unicodeFilePath = to_unicode_safe(file_path)
     else:
         unicodeFilePath = file_path
-        file_path = file_path.encode("utf8")
+        file_path = file_path.encode("utf8", "surrogateescape")
 
     if not os.path.isfile(unicodeFilePath):
         return md5(file_path).hexdigest()
@@ -1008,14 +1007,14 @@ reSuffixByteRangeSpecifier = re.compile("(-([0-9]+))")
 
 def obtain_content_ranges(rangetext, filesize):
     """
-   returns tuple (list, value)
+    returns tuple (list, value)
 
-   list
-       content ranges as values to their parsed components in the tuple
-       (seek_position/abs position of first byte, abs position of last byte, num_of_bytes_to_read)
-   value
-       total length for Content-Length
-   """
+    list
+        content ranges as values to their parsed components in the tuple
+        (seek_position/abs position of first byte, abs position of last byte, num_of_bytes_to_read)
+    value
+        total length for Content-Length
+    """
     listReturn = []
     seqRanges = rangetext.split(",")
     for subrange in seqRanges:
